import fedmsg.consumers

from . import config
from .jobtrigger import JobTrigger
from . import exceptions as exc

MESSAGE_TYPE = 'DistGitCommit'
ITEM_TYPE = 'dist_git_commit'


class DistGitCommitJobTrigger(JobTrigger):
    def process(self, msg):
        namespace = msg['msg']['commit']['namespace']
        repo = msg['msg']['commit']['repo']
        branch = msg['msg']['commit']['branch']
        rev = msg['msg']['commit']['rev']
        item = "%s/%s#%s" % (namespace, repo, rev)

        data = {
            "_msg": msg,
            "message_type": MESSAGE_TYPE,
            "item": item,
            "item_type": ITEM_TYPE,
            "namespace": namespace,
            "repo": repo,
            "distgit_branch": branch,
            "rev": rev,
        }
        return data


class DistGitCommitJobConsumer(fedmsg.consumers.FedmsgConsumer):
    topic = "org.fedoraproject.%s.git.receive" % config.deployment_type
    config_key = 'taskotron.distgitcommitjobconsumer.enabled'

    def __init__(self, *args, **kw):
        super(DistGitCommitJobConsumer, self).__init__(*args, **kw)
        self.trigger = DistGitCommitJobTrigger(self.log)

    def consume(self, message):
        msg = message['body']
        try:
            data = self.trigger.process(msg)
            self.trigger.do_trigger(data)
        except exc.TriggerMsgError as e:
            self.log.debug(e)
            return
