import koji
import fedmsg
import fedmsg.encoding
import fedmsg.consumers

from . import config, utils
from .jobtrigger import JobTrigger
from . import exceptions as exc

MESSAGE_TYPE = "GitHubPullRequestOpened"
ITEM_TYPE = "pull_request"


class GithubPullRequestOpenedJobTrigger(JobTrigger):

    def process(self, msg):

        data = {
            "_msg": msg,
            "message_type": MESSAGE_TYPE,
            "item": msg['msg']['pull_request']['html_url'],
            "item_type": ITEM_TYPE,
            "git_host": "github",
            "repo_name": msg['msg']['repository']['full_name'],
        }
        return data


class GithubPullRequestOpenedJobConsumer(fedmsg.consumers.FedmsgConsumer):
    topic = "org.fedoraproject.%s.github.pull_request.opened" % config.deployment_type
    jsonify = False
    config_key = 'taskotron.githubpropenedjobconsumer.enabled'

    def __init__(self, *args, **kw):
        super(GithubPullRequestOpenedJobConsumer, self).__init__(*args, **kw)
        self.trigger = GithubPullRequestOpenedJobTrigger(self.log)

    def consume(self, message):
        msg = fedmsg.encoding.loads(message.body)
        try:
            data = self.trigger.process(msg)
            self.trigger.do_trigger(data)
        except exc.TriggerMsgError as e:
            self.log.debug(e)
            return
