import fedmsg.consumers

from . import config
from .jobtrigger import JobTrigger
from . import exceptions as exc

MESSAGE_TYPE = 'ModuleBuildComplete'
ITEM_TYPE = 'module_build'


class ModuleBuildDoneJobTrigger(JobTrigger):
    def process(self, msg):
        item = '{name}-{stream}-{version}'.format(**msg['msg'])
        if msg['msg']['state_name'] != 'done':
            raise(exc.TriggerMsgError('rejecting message for not being module complete build'
                                      ' - %s' % item))

        data = {
            "_msg": msg,
            "message_type": MESSAGE_TYPE,
            "item": item,
            "item_type": ITEM_TYPE,
        }
        return data


class ModuleBuildDoneJobConsumer(fedmsg.consumers.FedmsgConsumer):
    topic = "org.fedoraproject.%s.mbs.module.state.change" % config.deployment_type
    config_key = 'taskotron.modulebuilddonejobconsumer.enabled'

    def __init__(self, *args, **kw):
        super(ModuleBuildDoneJobConsumer, self).__init__(*args, **kw)
        self.trigger = ModuleBuildDoneJobTrigger(self.log)

    def consume(self, message):
        msg = message['body']
        try:
            data = self.trigger.process(msg)
            self.trigger.do_trigger(data)
        except exc.TriggerMsgError as e:
            self.log.debug(e)
            return
