import fedmsg.consumers

from . import config
from .jobtrigger import JobTrigger
from . import exceptions as exc

MESSAGE_TYPE = 'PagureGitReceive'
ITEM_TYPE = 'git_commit'


class PagureGitReceiveJobTrigger(JobTrigger):
    def process(self, msg):
        server = 'https://pagure.io'
        namespace = msg['msg']['repo']['namespace']
        repo = msg['msg']['repo']['name']
        branch = msg['msg']['branch']
        start_commit = msg['msg']['start_commit']
        end_commit = msg['msg']['end_commit']

        if namespace:
            repo = "%s/%s" % (namespace, repo)
        item = "%s/%s#%s#%s" % (server, repo, branch, end_commit)

        data = {
            "_msg": msg,
            "message_type": MESSAGE_TYPE,
            "item": item,
            "item_type": ITEM_TYPE,
            "server": server,
            "repo": repo,
            "branch": branch,
            "start_commit": start_commit,
            "end_commit": end_commit,
        }
        return data


class PagureGitReceiveJobConsumer(fedmsg.consumers.FedmsgConsumer):
    topic = "io.pagure.%s.pagure.git.receive" % config.deployment_type
    config_key = 'taskotron.paguregitreceivejobconsumer.enabled'

    def __init__(self, *args, **kw):
        super(PagureGitReceiveJobConsumer, self).__init__(*args, **kw)
        self.trigger = PagureGitReceiveJobTrigger(self.log)

    def consume(self, message):
        msg = message['body']
        try:
            data = self.trigger.process(msg)
            self.trigger.do_trigger(data)
        except exc.TriggerMsgError as e:
            self.log.debug(e)
            return
