import fedmsg.consumers

from . import config
from .jobtrigger import JobTrigger
from . import exceptions as exc

MESSAGE_TYPE = 'TaskotronResultMissing'

class TaskotronResultMissingJobTrigger(JobTrigger):
    def process(self, msg):
        item = msg['msg']['item']
        item_type = msg['msg']['item_type']
        testcase = msg['msg']['testcase']
        if 'arch' in msg['msg']:
            arches = [msg['msg']['arch']]
        else:
            arches = config.valid_arches

        data = {
            "_msg": msg,
            "message_type": MESSAGE_TYPE,
            "item": item,
            "item_type": item_type,
            "testcase": testcase,
            "arches": arches,
        }
        return data


class TasktoronResultMissingJobConsumer(fedmsg.consumers.FedmsgConsumer):
    topic = "org.fedoraproject.%s.taskotron.result.missing" % config.deployment_type
    config_key = 'taskotron.taskotronresultmissingjobconsumer.enabled'

    def __init__(self, *args, **kw):
        super(TasktoronResultMissingJobConsumer, self).__init__(*args, **kw)
        self.trigger = TaskotronResultMissingJobTrigger(self.log)

    def consume(self, message):
        msg = fedmsg.encoding.loads(message.body)
        try:
            data = self.trigger.process(msg)
            self.trigger.do_trigger(data)
        except exc.TriggerMsgError as e:
            self.log.debug(e)
            return
